@@ -49,19 +49,20 @@ class objearth():
         pixel_qa    = xarray.where(mask0,self.Dataset1.pixel_qa,self.Dataset0.pixel_qa)
         # Create DataArray
         return xarray.merge([blue,green,red,nir,pixel_qa])
-    def plotshow(self,DataArray,lst=True):
-        self.DataArray = DataArray
-        self.lst = lst
-        if type(self.DataArray) == xarray.core.dataarray.DataArray:
-            if self.lst==True:
-                ymax = 0 ; ymin = self.DataArray.shape[0]
-                xmin = 0 ; xmax = self.DataArray.shape[1] 
+    @staticmethod
+    def plotshow(DataArray,lst=True):
+        DataArray = DataArray
+        lst = lst
+        if type(DataArray) == xarray.core.dataarray.DataArray:
+            if lst==True:
+                ymax = 0 ; ymin = DataArray.shape[0]
+                xmin = 0 ; xmax = DataArray.shape[1] 
             else:
-                ymax = self.lst[0] ; ymin = self.lst[1]
-                xmin = self.lst[2] ; xmax = self.lst[3]
-            lon  =  self.DataArray.longitude.to_numpy()[xmin:xmax]
+                ymax = lst[0] ; ymin = lst[1]
+                xmin = lst[2] ; xmax = lst[3]
+            lon  =  DataArray.longitude.to_numpy()[xmin:xmax]
             lon0 =  lon[0] ; lon1 =  lon[-1]
-            lat  =  self.DataArray.latitude.to_numpy()[ymax:ymin]
+            lat  =  DataArray.latitude.to_numpy()[ymax:ymin]
             lat0 = -lat[-1] ; lat1 = -lat[0]
             def longitude(lon):
                 return [lon0,lon1]
@@ -73,7 +74,7 @@ class objearth():
             fig.set_size_inches(7,7)
             ax.set_xlabel('x axis size')
             ax.set_ylabel('y axis size')
-            ax.imshow(self.DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
+            ax.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
             secax_x = ax.secondary_xaxis('top',functions=(longitude,axis))
             secax_x.set_xlabel('longitude')
             secax_x = ax.secondary_xaxis('top',functions=(longitude,axis))
@@ -82,22 +83,22 @@ class objearth():
             secax_y.set_ylabel('latitute')
             plt.grid(color='w', linestyle='-', linewidth=0.15)
             plt.show()
-        elif type(self.DataArray) == numpy.ndarray:
-            if self.lst==True:
-                ymax = 0 ; ymin = self.DataArray.shape[0]
-                xmin = 0 ; xmax = self.DataArray.shape[1]
+        elif type(DataArray) == numpy.ndarray:
+            if lst==True:
+                ymax = 0 ; ymin = DataArray.shape[0]
+                xmin = 0 ; xmax = DataArray.shape[1]
             else:
-                ymax = self.lst[0] ; ymin = self.lst[1]
-                xmin = self.lst[2] ; xmax = self.lst[3]
+                ymax = lst[0] ; ymin = lst[1]
+                xmin = lst[2] ; xmax = lst[3]
             plt.figure(figsize=(8,8))
-            plt.imshow(self.DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
+            plt.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
             plt.xlabel("x axis size")
             plt.ylabel("y axis size")
             plt.grid(color='w', linestyle='-', linewidth=0.15)
             plt.show()
 
         else:
-            print("Nonetype :",type(self.DataArray))
+            print("Nonetype :",type(DataArray))
     def percentcloud(self,Dataset):
         self.Dataset = Dataset
         FashCloud = [352,480,944]
